﻿using System.Security.Cryptography;

using Microsoft.AspNetCore.Http;

namespace anbs_cp.Classes;

/// <summary>
/// Класс для работы с хэшем файла
/// </summary>
public class FileHash
{
    /// <summary>
    /// Получение md5-хэша файла.
    /// Взято с https://stackoverflow.com/a/24031467/16469671
    /// </summary>
    /// <param name="fileName">Имя файла</param>
    /// <returns>Массив хэша</returns>
    public FileHash (string fileName)
    {
        using MD5 md5 = MD5.Create();
        using FileStream stream = File.OpenRead(fileName);
        Hash = md5.ComputeHash(stream);
    }

    /// <summary>
    /// Получение md5-хэша загружаемого файла.
    /// Взято с https://stackoverflow.com/a/67081012/16469671
    /// </summary>
    /// <param name="file">Загружаемый файл</param>
    /// <returns>Массив хэша</returns>
    public FileHash (IFormFile file)
    {
        using MD5 md5 = MD5.Create();
        using StreamReader streamReader = new(file.OpenReadStream());
        Hash = md5.ComputeHash(streamReader.BaseStream);
    }

    /// <summary>
    /// Хэш файла
    /// </summary>
    public byte[] Hash { get; }

    /// <summary>
    /// Вывод в строку
    /// </summary>
    /// <returns>Строка хэша файла</returns>
    public override string ToString () => BitConverter.ToString(Hash).Replace("-", "").ToLowerInvariant();
}